#include "kernelmessageswindow.h"
#include "ui_kernelmessageswindow.h"

KernelMessagesWindow::KernelMessagesWindow(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::KernelMessagesWindow)
{
    ui->setupUi(this);
    setAttribute(Qt::WA_DeleteOnClose);
    connect(ui->actionExport, SIGNAL(triggered()), this, SLOT(exportlogs()));
#ifdef Q_WS_MAEMO_5
    setAttribute(Qt::WA_Maemo5StackedWindow);
#endif
    QMainWindow::setCentralWidget(ui->textBrowser);
}

KernelMessagesWindow::~KernelMessagesWindow()
{
    delete ui;
    system("rm /root/.tempdmesg 2> /dev/null");
}

void KernelMessagesWindow::showLogs()
{
    system("dmesg | sed 's/$/\\<br\\>/' > /root/.tempdmesg");
    ui->textBrowser->setSource(QUrl("file:///root/.tempdmesg"));
}

void KernelMessagesWindow::exportlogs()
{
    system("dmesg > /home/user/MyDocs/hostmode.txt");
#ifdef Q_WS_MAEMO_5
    QMaemo5InformationBox::information(0, tr("Saved to /home/user/MyDocs/hostmode.txt"));
#endif
}
